@@ -12,7 +12,8 @@ from open_dread_rando.exefs import patch_exefs
 from open_dread_rando.logger import LOG
 from open_dread_rando.lua_editor import LuaEditor
 from open_dread_rando.patcher_editor import PatcherEditor
-from open_dread_rando.pickup import patch_text, pickup_object_for
+from open_dread_rando.pickup import pickup_object_for
+from open_dread_rando.text_patches import apply_text_patches, patch_hints, patch_text
 
 T = typing.TypeVar("T")
 
@@ -65,8 +66,7 @@ def apply_one_sided_door_fixes(editor: PatcherEditor):
             if "db_hdoor" in other.oActorDefLink:
                 continue
 
-            LOG.debug("[{:>15}/{}] ({:>20}) copy {} into {}".format(scenario_name, layer_name, actor_name, other.sName,
-                                                                    direction))
+            LOG.debug("%s/%s/%s: copy %s into %s", scenario_name, layer_name, actor_name, other.sName, direction)
             mirrored = copy.deepcopy(other)
             mirrored.sName += "_mirrored"
             mirrored.vAng = [other.vAng[0], -other.vAng[1], other.vAng[2]]
@@ -92,7 +92,11 @@ def apply_static_fixes(editor: PatcherEditor):
     apply_one_sided_door_fixes(editor)
 
 
-def create_custom_init(editor: PatcherEditor, inventory: dict[str, int], starting_location: dict, starting_text: list[list[str]]):
+def create_custom_init(editor: PatcherEditor, configuration: dict):
+    inventory: dict[str, int] = configuration["starting_items"]
+    starting_location: dict = configuration["starting_location"]
+    starting_text: list[list[str]] = configuration.get("starting_text", [])
+    
     # Game doesn't like to start if some fields are missing, like ITEM_WEAPON_POWER_BOMB_MAX
     final_inventory = {
         "ITEM_MAX_LIFE": 99,
@@ -122,20 +126,22 @@ def create_custom_init(editor: PatcherEditor, inventory: dict[str, int], startin
         "new_game_inventory": final_inventory,
         "starting_scenario": lua_util.wrap_string(starting_location["scenario"]),
         "starting_actor": lua_util.wrap_string(starting_location["actor"]),
-        "textbox_count": textboxes
+        "textbox_count": textboxes,
+        "energy_per_tank": configuration.get("energy_per_tank", 100.0),
+        "immediate_energy_parts": configuration.get("immediate_energy_parts", False),
     }
 
     return lua_util.replace_lua_template("custom_init.lua", replacement)
 
 
-def patch_pickups(editor: PatcherEditor, lua_scripts: LuaEditor, pickups_config: list[dict]):
+def patch_pickups(editor: PatcherEditor, lua_scripts: LuaEditor, pickups_config: list[dict], configuration: dict):
     # add to the TOC
     editor.add_new_asset("actors/items/randomizer_powerup/scripts/randomizer_powerup.lc", b'', [])
 
     for i, pickup in enumerate(pickups_config):
         LOG.debug("Writing pickup %d: %s", i, pickup["resources"][0]["item_id"])
         try:
-            pickup_object_for(lua_scripts, pickup, i).patch(editor)
+            pickup_object_for(lua_scripts, pickup, i, configuration).patch(editor)
         except NotImplementedError as e:
             LOG.warning(e)
 
@@ -166,12 +172,7 @@ def patch(input_path: Path, output_path: Path, configuration: dict):
     lua_util.create_script_copy(editor, "system/scripts/init")
     editor.replace_asset(
         "system/scripts/init.lc",
-        create_custom_init(
-            editor,
-            configuration["starting_items"],
-            configuration["starting_location"],
-            configuration["starting_text"],
-        ).encode("ascii"),
+        create_custom_init(editor, configuration).encode("ascii"),
     )
 
     # Update scenario.lc
@@ -182,7 +183,15 @@ def patch(input_path: Path, output_path: Path, configuration: dict):
         elevator.patch_elevators(editor, configuration["elevators"])
 
     # Pickups
-    patch_pickups(editor, lua_scripts, configuration["pickups"])
+    patch_pickups(editor, lua_scripts, configuration["pickups"], configuration)
+
+    # Hints
+    if "hints" in configuration:
+        patch_hints(editor, configuration["hints"])
+    
+    # Text patches
+    if "text_patches" in configuration:
+        apply_text_patches(editor, configuration["text_patches"])
 
     # Exefs
     LOG.info("Creating exefs patches")
