@@ -888,28 +888,14 @@ end
 
 
 function s070_basesanc.OnEnter_AP_08()
-  local L0_2 = Game.GetActor("accesspoint_000")
-  local L1_2 = Blackboard.GetProp("GAME_PROGRESS", "ADAMDIALOGUE")
-  if L0_2 ~= nil then
-    if L1_2 == "DIAG_ADAM_FOREST_2" then
-      L0_2.USABLE:ActiveDialogue("DIAG_ADAM_SANC_1")
-      Blackboard.SetProp("GAME_PROGRESS", "ADAMDIALOGUE", "s", "DIAG_ADAM_SANC_1")
-    elseif L1_2 == "DIAG_ADAM_CAVE_4" then
-      local L2_2 = Blackboard.GetProp("PLAYER_INVENTORY", "ITEM_SCREW_ATTACK")
-      if L2_2 ~= nil and L2_2 > 0 then
-        L0_2.USABLE:ActiveDialogue("DIAG_ADAM_AQUA_3")
-        Blackboard.SetProp("GAME_PROGRESS", "ADAMDIALOGUE", "s", "DIAG_ADAM_AQUA_3")
-      end
-    else
-      local L2_2 = Blackboard.GetProp("s070_basesanc", "accesspoint_000:USABLE:Used")
-      if L2_2 ~= true then
-        L0_2.USABLE:ActiveDialogue("")
-      end
-    end
-  end
+  Scenario.CheckRandoHint("accesspoint_000", "SANC_1")
 end
 
-
+function s070_basesanc.OnUsableFinishInteract(_ARG_0_)
+  if _ARG_0_.sName == "accesspoint_000" then
+    Scenario.SetRandoHintSeen()
+  end
+end
 
 
 
