@@ -4,11 +4,12 @@ import json
 from enum import Enum
 from pathlib import Path
 
-from mercury_engine_data_structures.formats import Bmsad, Txt
+from mercury_engine_data_structures.formats import Bmsad
 
 from open_dread_rando import model_data
 from open_dread_rando.lua_editor import LuaEditor
 from open_dread_rando.patcher_editor import PatcherEditor, path_for_level
+from open_dread_rando.text_patches import patch_text
 
 EXPANSION_ITEM_IDS = {
     "ITEM_ENERGY_TANKS",
@@ -18,23 +19,6 @@ EXPANSION_ITEM_IDS = {
     "ITEM_WEAPON_POWER_BOMB",
 }
 
-# may want to edit all the localization files?
-ALL_TEXT_FILES = {
-    # "eu_dutch.txt",
-    # "eu_french.txt",
-    # "eu_german.txt",
-    # "eu_italian.txt",
-    # "eu_spanish.txt",
-    # "japanese.txt",
-    # "korean.txt",
-    # "russian.txt",
-    # "simplified_chinese.txt",
-    # "traditional_chinese.txt",
-    "us_english.txt",
-    # "us_french.txt",
-    # "us_spanish.txt"
-}
-
 
 @functools.cache
 def _read_template_powerup():
@@ -50,10 +34,11 @@ class PickupType(Enum):
 
 
 class BasePickup:
-    def __init__(self, lua_editor: LuaEditor, pickup: dict, pickup_id: int):
+    def __init__(self, lua_editor: LuaEditor, pickup: dict, pickup_id: int, configuration: dict):
         self.lua_editor = lua_editor
         self.pickup = pickup
         self.pickup_id = pickup_id
+        self.configuration = configuration
 
     def patch(self, editor: PatcherEditor):
         raise NotImplementedError()
@@ -68,9 +53,14 @@ class ActorPickup(BasePickup):
         item_id: str = self.pickup["resources"][0]["item_id"]
         quantity: float = self.pickup["resources"][0]["quantity"]
 
-        if item_id == "ITEM_ENERGY_TANKS":
+        if (item_id == "ITEM_ENERGY_TANKS"
+            or (item_id == "ITEM_LIFE_SHARDS"
+            and self.configuration.get("immediate_energy_parts", False))
+        ):
             item_id = "fMaxLife"
-            quantity *= 100.0
+            quantity *= self.configuration.get("energy_per_tank", 100.0)
+            if item_id == "ITEM_LIFE_SHARDS":
+                quantity /= 4
             set_custom_params["Param4"]["value"] = "Full"
             set_custom_params["Param5"]["value"] = "fCurrentLife"
             set_custom_params["Param6"]["value"] = "LIFE"
@@ -137,10 +127,9 @@ class ActorPickup(BasePickup):
         template_bmsad = _read_template_powerup()
 
         pickup_actor = self.pickup["pickup_actor"]
-        pkgs_for_level = set(editor.find_pkgs(path_for_level(pickup_actor["scenario"]) + ".brfld"))
-        level = editor.get_scenario(pickup_actor["scenario"])
-        actor = level.actors_for_layer(pickup_actor["layer"])[pickup_actor["actor"]]
-
+        pkgs_for_level = editor.get_level_pkgs(pickup_actor["scenario"])
+        actor = editor.resolve_actor_reference(pickup_actor)
+        
         model_name: str = self.pickup["model"]
         selected_model_data = model_data.get_data(model_name)
 
@@ -232,11 +221,6 @@ class ActorDefPickup(BasePickup):
     def patch(self, editor: PatcherEditor):
         raise NotImplementedError()
 
-def patch_text(editor: PatcherEditor, key: str, value: str):
-    for text_file in ALL_TEXT_FILES:
-        text = editor.get_file(f"system/localization/{text_file}", Txt)
-        text.strings[key] = value
-
 class EmmiPickup(ActorDefPickup):
     def patch(self, editor: PatcherEditor):
         bmsad_path, actordef = self._patch_actordef_pickup(editor, "sInventoryItemOnKilled")
@@ -273,6 +257,6 @@ _PICKUP_TYPE_TO_CLASS = {
 }
 
 
-def pickup_object_for(lua_scripts: LuaEditor, pickup: dict, pickup_id: int) -> "BasePickup":
+def pickup_object_for(lua_scripts: LuaEditor, pickup: dict, pickup_id: int, configuration: dict) -> "BasePickup":
     pickup_type = PickupType(pickup["pickup_type"])
-    return _PICKUP_TYPE_TO_CLASS[pickup_type](lua_scripts, pickup, pickup_id)
+    return _PICKUP_TYPE_TO_CLASS[pickup_type](lua_scripts, pickup, pickup_id, configuration)
