@@ -3,6 +3,8 @@ Game.ImportLibrary("system/scripts/init_original.lua")
 Init.tNewGameInventory = TEMPLATE("new_game_inventory")
 
 Init.iNumRandoTextBoxes = TEMPLATE("textbox_count")
+Init.fEnergyPerTank = TEMPLATE("energy_per_tank")
+Init.bImmediateEnergyParts = TEMPLATE("immediate_energy_parts")
 
 Game.LogWarn(0, "Inventory:")
 for k, v in pairs(Init.tNewGameInventory) do
